.. Pyramid SNA documentation master file, created by
   sphinx-quickstart on Tue Apr 30 09:46:57 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Pyramid SNA's documentation!
=======================================

Pyramid Social Network Authentication is a small package that lets you use
Social Network Authentication in your Pyramid project very easily.

Contents:

.. toctree::
   :maxdepth: 2

   configuration
   supported_providers


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

